# Session Reminder

**Session Reminder** is a Drupal 10 module designed to displays a modal before the User's session is about to expire, giving the user the option to extend the session duration in order to prevent log-out.

## Table of contents

- Features
- Configuration
- Installation
- Usage
- Troubleshooting
- Maintainers
- License

## Features

- **Pre-expiration Notification**: The module will show a modal window before the session expires, based on the `cookie_lifetime` value defined in the `services.yml` file.
- **Session Extension**: The modal includes a button that, when clicked, updates the session cookie’s expiration time according to the `cookie_lifetime` value. This prevents users from losing their current session.
- **Customizable**: The module allows administrators to configure when the modal should appear and for which user roles it should be visible (excluding anonymous users).
- **Configuration Page**: Configure the module at `/admin/config/session-reminder`.
- **Graceful UX**: Ensure the alert does not interrupt the user experience.

## Configuration

You can configure the following options at `/admin/config/session-reminder`:

- **Warning Threshold**: Set how many seconds before the session expiration the modal should appear.
- **Roles**: Choose which user roles should see the notification (only for authenticated users).

### Cookie Lifetime

The module uses the `cookie_lifetime` value to calculate the session duration.
The `cookie_lifetime` value defines the number of seconds the session cookie is valid after user login.

- **cookie_lifetime**: This is the session duration defined in Drupal's `services.yml` file. It determines how long the session cookie is valid.  The default value is `200000` seconds (approximately 56 hours).

- **gc_maxlifetime**: This is the maximum lifetime of a session stored in session storage. If set to `0`, it means there is **no expiration** for session data.  The default value is `200000` seconds (approximately 56 hours), but it may vary based on server settings.

If `gc_maxlifetime` is set to `0` (meaning no expiration), the **Session Reminder** module will display an alert on the configuration page stating that the session cookie has no expiration so the modal cannot be shown.

## Installation

1. Download and install the module in your Drupal installation.
2. Enable the module via the admin interface or Drush:

   ```bash
   drush en session_reminder
3. Configure the module at /admin/config/session-reminder

## Usage

Once the module is enabled and configured, authenticated users will see the session expiration reminder modal based on the configured notification timing.
- The modal will display the remaining time before the session expires.
- The user can click the "Extend Session" button to extend their own session time.
- The modal behavior is based on the user roles selected in the configuration page.

## Troubleshooting
**No Modal Appears**: If the modal is not showing, ensure that the cookie_lifetime value is set correctly and that gc_maxlifetime is not set to 0.
**Please note**: The modal will only start appearing for users who log in after the module is installed (it will not have an immediate effect on users who are already logged in).

## Maintainer

Current maintainers:

- [Pietro Raffa (PietroR91)](https://www.drupal.org/u/pietror91)

## License
This module is licensed under the GNU General Public License, version 2 or later.
For more information, visit: https://www.gnu.org/licenses/gpl-2.0.html
