<?php

namespace Drupal\session_reminder\Helper;


use Drupal\user\Entity\User;

class SessionReminderHelper {

  /**
   * Check if user is authenticated and Role enabled to show alert
   *
   * @return bool
   */
  public static function userEnabled() {
    $user = \Drupal::currentUser();
    $authenticated = $user->isAuthenticated();
    $expTimestamp = SessionHelper::getExpTimestamp();

    if ($authenticated && !empty($expTimestamp)) {
      //If not setted start session timestamp on hook login, not load modal.
      $roles = array_flip($user->getRoles());
      $roles['all'] = TRUE;
      $enabledRoles = \Drupal::config('session_reminder.settings')
        ->get('roles');

      return (count(array_intersect_key($roles, $enabledRoles)) >= 1);
    }

    return FALSE;
  }


  public static function getCookieLifetime() {
    return ini_get("session.cookie_lifetime");
  }

  public static function getCurrentUserTimezone() {
    $currentUser = \Drupal::currentUser();
    $user = User::load($currentUser->id());

    if ($user && !$user->isAnonymous()) {
      // Check if the user has a custom timezone.
      $timezone = $user->get('timezone')->value;
      if (!empty($timezone)) {
        return $timezone;
      }
    }

    // Fallback to the site's default timezone if user doesn't have a custom one.
    return \Drupal::config('system.date')->get('timezone.default');
  }

}
